dag_cbor.ipld
=============

.. automodule:: dag_cbor.ipld

Kind
----

.. autodata:: dag_cbor.ipld.Kind

Path
----

.. autoclass:: dag_cbor.ipld.Path
    :show-inheritance:
    :members:
    :special-members: __new__, __truediv__, __rtruediv__, __le__, __lt__, __repr__, __rshift__

ScalarKind
----------

.. autodata:: dag_cbor.ipld.ScalarKind

Segment
-------

.. autodata:: dag_cbor.ipld.Segment
